==> phoenix-5.2.0-src.tar.gz: phoenix-5.2.0/phoenix-core-client/src/main/java/org/apache/phoenix/query/PropertyPolicyProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.query;

import org.apache.phoenix.util.InstanceResolver;

/**
 * Manages providers that provide property policy for Phoenix.
 * 
 * Dependent modules may register their own implementations of the following using {@link java.util.ServiceLoader}:
 * <ul>
 *     <li>{@link PropertyPolicy}</li>
 * </ul>
 *
 * If a custom implementation is not registered, the default implementations will be used.
 *
 */
public class PropertyPolicyProvider {
    private static final PropertyPolicy DEFAULT_PROPERTY_POLICY = new PropertyPolicy.PropertyPolicyImpl();

    public static PropertyPolicy getPropertyPolicy(){
        return InstanceResolver.getSingleton(PropertyPolicy.class, DEFAULT_PROPERTY_POLICY);
    }
}

==> phoenix-5.3.0-src.tar.gz: phoenix-5.3.0/phoenix-core-client/src/main/java/org/apache/phoenix/query/PropertyPolicyProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.query;

import org.apache.phoenix.util.InstanceResolver;

/**
 * Manages providers that provide property policy for Phoenix. Dependent modules may register their
 * own implementations of the following using {@link java.util.ServiceLoader}:
 * <ul>
 * <li>{@link PropertyPolicy}</li>
 * </ul>
 * If a custom implementation is not registered, the default implementations will be used.
 */
public class PropertyPolicyProvider {
  private static final PropertyPolicy DEFAULT_PROPERTY_POLICY =
    new PropertyPolicy.PropertyPolicyImpl();

  public static PropertyPolicy getPropertyPolicy() {
    return InstanceResolver.getSingleton(PropertyPolicy.class, DEFAULT_PROPERTY_POLICY);
  }
}
